# Table of Contents

- [application-modernization-collect-data](<./application-modernization-collect-data.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 3: Collect Data](<./Step-3-Collect-Data.md>)
  - [Collect Data from Experts](<./Step-3-Collect-Data/Collect-Data-from-Experts.md>)
  - [Use To-Dos to Manage Data Collection](<./Step-3-Collect-Data/Use-To-Dos-to-Manage-Data-Collection.md>)
  - [Collect Data from Integrations](<./Step-3-Collect-Data/Collect-Data-from-Integrations.md>)
